
/**
 * Helper for <form> nodes
 *
 * @author www.namerobot.com (Henning Leutz)
 */

define('qui/utils/Form', function()
{
    "use strict";

    return {

        /**
         * Set an object to an formular DOMNode
         * goes through all object attributes and set it to the appropriate form elements
         *
         * @method QUI.lib.Utils#setDataToForm
         *
         * @param {Object} data
         * @param {DOMNode} form - Formular
         */
        setDataToForm : function(data, form)
        {
            if ( typeof form === 'undefined' || form.nodeName !== 'FORM' ) {
                return;
            }

            var i, k, len, Elm;

            data = data || {};

            for ( k in data )
            {
                if ( !form.elements[ k ] ) {
                    continue;
                }

                Elm = form.elements[ k ];

                if ( Elm.type === 'checkbox' )
                {
                    if ( data[k] === false || data[k] === true )
                    {
                        Elm.checked = data[k];
                        continue;
                    }

                    Elm.checked = ( (data[k]).toInt() ? true : false );
                    continue;
                }

                if ( Elm.type === 'text' ||
                     Elm.type === 'textarea' ||
                     Elm.type === 'select' ||
                     Elm.type === 'hidden' )
                {
                    Elm.value = data[k];
                    continue;
                }

                if ( Elm.length )
                {
                    for ( i = 0, len = Elm.length; i < len; i++ )
                    {
                        if ( Elm[i].type !== 'radio' ) {
                            continue;
                        }

                        if ( Elm[i].value == data[k] ) {
                            Elm[i].checked = true;
                        }
                    }

                    continue;
                }
            }
        },

        /**
         * Get all Data from a Formular
         *
         * @method QUI.lib.Utils#getFormData
         *
         * @param {DOMNode} form - DOMNode Formular
         * @return {Object}
         */
        getFormData : function(form)
        {
            if ( typeof form === 'undefined' || !form ) {
                return {};
            }

            var i, len, Elm;
            var result   = {},
                elements = form.elements;

            for ( i = 0, len = elements.length; i < len; i++ )
            {
                Elm = elements[i];

                if ( Elm.type === 'text' ||
                     Elm.type === 'textarea' ||
                     Elm.type === 'select' ||
                     Elm.type === 'select-one' ||
                     Elm.type === 'select-multiple' ||
                     Elm.type === 'hidden' )
                {
                    result[ Elm.name ] = Elm.value;
                    continue;
                }

                if ( Elm.type === 'checkbox' )
                {
                    result[ Elm.name ] = Elm.checked ? true : false;
                    continue;
                }

                if ( Elm.type === 'radio' && !Elm.length )
                {
                    if ( Elm.checked ) {
                        result[ Elm.name ] = Elm.value;
                    }

                    continue;
                }

                if ( Elm.length )
                {
                    for ( i = 0, len = Elm.length; i < len; i++ )
                    {
                        if ( Elm[i].type !== 'radio' ) {
                            continue;
                        }

                        result[ Elm[i].name ] = '';

                        if ( Elm[i].checked )
                        {
                            result[ Elm[i].name ] = Elm[i].value;
                            break;
                        }
                    }
                }
            }

            return result;
        }

    };
});